import Header from "@/components/Header"
import { Interactives } from "@/components/header/Interactives"
import Defaults from "@/defaults"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"
import { CalendarDays, Clock } from "lucide-react"

const posts = [
  {
    id: 1,
    title: "Post Ex 1",
    description: "Just another example post",
    date: "2025-04-22",
    readTime: "5 min read",
    category: "Amazing Category"
  },
  {
    id: 2,
    title: "Post Ex 2",
    description: "Just another example post",
    date: "2025-04-22",
    readTime: "4 min read",
    category: "Fantastic Category"
  },
]

export default function Home() {
  return (
    <main className="min-h-screen bg-background text-foreground">
      <Header />
      <div className="pt-32 px-4 max-w-7xl mx-auto">
        <h1 className="text-4xl font-bold">{process.env.NEXT_PUBLIC_MBLOG_NAME || Defaults.blogName}</h1>
        <p className="mt-4 text-lg text-muted-foreground">
          {Defaults.blogDescription}
        </p>

        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6 mt-12">
          {posts.map((post) => (
            <Interactives key={post.id} className="rounded-xl">
              <Card className="h-full">
                <CardHeader>
                  <div className="text-sm text-muted-foreground mb-2">{post.category}</div>
                  <CardTitle className="text-2xl">{post.title}</CardTitle>
                  <CardDescription>{post.description}</CardDescription>
                </CardHeader>
                <CardContent>
                  <div className="flex items-center gap-4 text-sm text-muted-foreground">
                    <div className="flex items-center gap-1">
                      <CalendarDays className="w-4 h-4" />
                      <span>{post.date}</span>
                    </div>
                    <div className="flex items-center gap-1">
                      <Clock className="w-4 h-4" />
                      <span>{post.readTime}</span>
                    </div>
                  </div>
                </CardContent>
                <CardFooter>
                  <button className="text-sm font-medium text-primary cursor-pointer hover:underline">
                    Read more →
                  </button>
                </CardFooter>
              </Card>
            </Interactives>
          ))}
        </div>
      </div>
    </main>
  )
}