import { useTheme } from "next-themes"
import { Loader, Moon } from "lucide-react"
import { ImSun } from "react-icons/im"
import { useEffect, useState } from "react"
import { motion } from "framer-motion"

export function ThemeToggle() {
  const { theme, setTheme } = useTheme()
  const [mounted, setMounted] = useState(false)

  useEffect(() => {
    import("framer-motion").then(() => {
      setMounted(true)
    })
  }, [])

  if (!mounted) {
    return (
      <button
        className="relative w-9 h-9 rounded-full bg-transparent flex items-center justify-center cursor-pointer"
        aria-label={theme === "dark" ? "Switch to light mode" : "Switch to dark mode"}
      >
        <div className="absolute inset-0 flex items-center justify-center text-purple-200 hover:text-purple-100">
          <Loader className="h-[18px] w-[18px] animate-spin" />
        </div>
      </button>
    )
  }

  return (
    <motion.button
      whileHover={{ scale: 1.05 }}
      whileTap={{ scale: 0.95 }}
      onClick={() => setTheme(theme === "dark" ? "light" : "dark")}
      className="relative w-9 h-9 rounded-full bg-transparent flex items-center justify-center cursor-pointer"
      aria-label={theme === "dark" ? "Switch to light mode" : "Switch to dark mode"}
    >
      <div className="absolute inset-0 flex items-center justify-center text-purple-200 hover:text-purple-100">
        {theme === "light" && <ImSun className="h-[18px] w-[18px] transition-all duration-300 rotate-0" />}
        {theme === "dark" && <Moon className="h-[18px] w-[18px] absolute transition-all duration-300 rotate-0" />}
      </div>
    </motion.button>
  )
}
